@@ -31,5 +31,5 @@ public interface EventTranslatorTwoArg<T, A, B>
      * @param arg0     The first user specified argument to the translator
      * @param arg1     The second user specified argument to the translator
      */
-    void translateTo(final T event, long sequence, final A arg0, final B arg1);
+    void translateTo(T event, long sequence, A arg0, B arg1);
 }
