@@ -15,12 +15,6 @@
  */
 package com.lmax.disruptor.translator;
 
-import static com.lmax.disruptor.support.PerfTestUtil.failIfNot;
-
-import java.util.concurrent.CountDownLatch;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
-
 import com.lmax.disruptor.AbstractPerfTestDisruptor;
 import com.lmax.disruptor.EventTranslatorOneArg;
 import com.lmax.disruptor.RingBuffer;
@@ -33,6 +27,10 @@ import com.lmax.disruptor.support.ValueEvent;
 import com.lmax.disruptor.util.DaemonThreadFactory;
 import com.lmax.disruptor.util.MutableLong;
 
+import java.util.concurrent.CountDownLatch;
+
+import static com.lmax.disruptor.support.PerfTestUtil.failIfNot;
+
 /**
  * <pre>
  * UniCast a series of items between 1 publisher and 1 event processor using the EventTranslator API
@@ -66,7 +64,6 @@ public final class OneToOneTranslatorThroughputTest extends AbstractPerfTestDisr
 {
     private static final int BUFFER_SIZE = 1024 * 64;
     private static final long ITERATIONS = 1000L * 1000L * 100L;
-    private final ExecutorService executor = Executors.newSingleThreadExecutor(DaemonThreadFactory.INSTANCE);
     private final long expectedResult = PerfTestUtil.accumulatedAddition(ITERATIONS);
     private final ValueAdditionEventHandler handler = new ValueAdditionEventHandler();
     private final RingBuffer<ValueEvent> ringBuffer;
@@ -80,7 +77,7 @@ public final class OneToOneTranslatorThroughputTest extends AbstractPerfTestDisr
         Disruptor<ValueEvent> disruptor =
             new Disruptor<ValueEvent>(
                 ValueEvent.EVENT_FACTORY,
-                BUFFER_SIZE, executor,
+                BUFFER_SIZE, DaemonThreadFactory.INSTANCE,
                 ProducerType.SINGLE,
                 new YieldingWaitStrategy());
         disruptor.handleEventsWith(handler);
